<?php
/**
 * Copyright © 2015 FiloBlu. All rights reserved.
 */

namespace FiloBlu\Flow\Setup;

use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\ModuleContextInterface;
/**
 * @codeCoverageIgnore
 */
class UpgradeSchema implements UpgradeSchemaInterface
{
    /**
     * {@inheritdoc}
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {

        if(!$context->getVersion()) {
           return $this;
        }

        if (version_compare($context->getVersion(), '0.0.2') < 0) {

            $this->addChannelsTable($setup,$context);

        }

        if (version_compare($context->getVersion(), '0.0.3') < 0) {

            $this->addIteTable($setup,$context);

        }

        if (version_compare($context->getVersion(), '0.0.4') < 0) {

            $this->addEavsTable($setup,$context);

        }

        if (version_compare($context->getVersion(), '0.0.5') < 0) {

            $this->addPriceTable($setup,$context);

        }


    }

    public function addChannelsTable ($setup,$context) {

        $installer = $setup;

        $installer->startSetup();

        /**
         * Create table 'flow_channels' if not exists
         */

        if (!$installer->tableExists('flow_channels')) {

            $table = $installer->getConnection()->newTable(
                $installer->getTable('flow_channels')
            )
                ->addColumn(
                    'id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
                    'flow_channels'
                )
                ->addColumn(
                    'name',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '40',
                    [],
                    'name'
                )
                ->addColumn(
                    'data',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '64k',
                    [],
                    'data'
                )
                ->addColumn(
                    'type',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '20',
                    [],
                    'type'
                )

                /*{{CedAddTableColumn}}}*/


                ->setComment(
                    'FiloBlu Flow flow_channels'
                );

            $installer->getConnection()->createTable($table);
            /*{{CedAddTable}}*/


        }

        $installer->endSetup();

    }

    public function addIteTable($setup,$context)
    {

        $installer = $setup;

        $installer->startSetup();

        /**
         * Create table 'flow_channels' if not exists
         */
        if (!$installer->tableExists('flow_from_ite')) {

            $table = $installer->getConnection()->newTable(
                $installer->getTable('flow_from_ite')
            )

                ->addColumn(
                    'sku',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '60',
                    [],
                    'sku'
                )
                ->addColumn(
                    'nome_articolo',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '100',
                    [],
                    'nome_articolo'
                )
//                ->addColumn(
//                    'codice_brand',
//                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
//                    '10',
//                    [],
//                    'codice_brand'
//                )
//
//                ->addColumn(
//                    'descrizione_brand',
//                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
//                    '100',
//                    [],
//                    'descrizione_brand'
//                )
                ->addColumn(
                    'codice_configurabile',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '30',
                    [],
                    'codice_configurabile'
                )

//                ->addColumn(
//                    'descrizione_famiglia',
//                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
//                    '100',
//                    ['nullable' => false,'default' => '0'],
//                    'descrizione_famiglia'
//                )
//                ->addColumn(
//                    'qta_minima_vendibile',
//                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
//                    '4',
//                    [],
//                    'qta_minima_vendibile'
//                )
//
//                ->addColumn(
//                    'qta_massima_vendibile',
//                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
//                    '4',
//                    [],
//                    'qta_massima_vendibile'
//                )
//                ->addColumn(
//                    'vendibilita_senza_stock',
//                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
//                    '1',
//                    [],
//                    'vendibilita_senza_stock'
//                )

                ->addColumn(
                    'fascia_iva_articoli',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '10',
                    [],
                    'fascia_iva_articoli'
                )
//                ->addColumn(
//                    'visibilita_su_store',
//                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
//                    '1',
//                    [],
//                    'visibilita_su_store'
//                )
                ->addColumn(
                    'meta_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
                    'flow_channels'
                )
                ->addColumn(
                    'meta_ref_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    '11',
                    [],
                    'meta_ref_id'
                )
                ->addColumn(
                    'meta_file',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [],
                    'meta_file'
                )

                ->addColumn(
                    'meta_processed',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    '1',
                    [],
                    'meta_processed'
                )
                ->addColumn(
                    'meta_insert_time',
                    \Magento\Framework\DB\Ddl\Table::TYPE_DATETIME,
                    '10',
                    ['unsigned' => true, 'nullable' => false],
                    'meta_insert_time'
                )

                ->addColumn(
                    'meta_process_time',
                    \Magento\Framework\DB\Ddl\Table::TYPE_DATETIME,
                    '10',
                    [],
                    'meta_process_time'
                )

                ->addIndex(
                    $installer->getIdxName('flow_from_ite_meta_file', ['meta_file']),
                    ['meta_file']
                )

                ->addForeignKey(
                    $installer->getFkName(
                        'flow_from_ite',
                        'meta_file',
                        'flow_inboundflow',
                        'id'
                    ),
                    'meta_file',
                    $installer->getTable('flow_inboundflow'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )

                /*{{CedAddTableColumn}}}*/


                ->setComment(
                    'FiloBlu Flow flow_channels'
                );

            $installer->getConnection()->createTable($table);
            /*{{CedAddTable}}*/

        }

        $installer->endSetup();

    }


    public function addEavsTable($setup,$context)
    {
        $installer = $setup;

        $installer->startSetup();

        /**
         * Create table 'flow_channels' if not exists
         */
        if (!$installer->tableExists('flow_from_eavs')) {

            $table = $installer->getConnection()->newTable(
                $installer->getTable('flow_from_eavs')
            )

                ->addColumn(
                    'e',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '255',
                    [],
                    'e'
                )
                ->addColumn(
                    'a',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '255',
                    [],
                    'a'
                )
                ->addColumn(
                    'v',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '65535',
                    [],
                    'v'
                )
                ->addColumn(
                    's',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '255',
                    [],
                    's'
                )
                ->addColumn(
                    'meta_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
                    'flow_channels'
                )
                ->addColumn(
                    'meta_ref_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    '11',
                    [],
                    'meta_ref_id'
                )
                ->addColumn(
                    'meta_file',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [],
                    'meta_file'
                )

                ->addColumn(
                    'meta_processed',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    '1',
                    [],
                    'meta_processed'
                )
                ->addColumn(
                    'meta_insert_time',
                    \Magento\Framework\DB\Ddl\Table::TYPE_DATETIME,
                    '10',
                    ['unsigned' => true, 'nullable' => false],
                    'meta_insert_time'
                )

                ->addColumn(
                    'meta_process_time',
                    \Magento\Framework\DB\Ddl\Table::TYPE_DATETIME,
                    '10',
                    [],
                    'meta_process_time'
                );                ;
        $installer->getConnection()->createTable($table);
            /*{{CedAddTable}}*/

        }

        $installer->endSetup();

    }

    public function addPriceTable ($setup,$context) {

        $installer = $setup;

        $installer->startSetup();

        /**
         * Create table 'flow_from_price' if not exists
         */
        if (!$installer->tableExists('flow_from_price')) {

            $table = $installer->getConnection()->newTable(
                $installer->getTable('flow_from_price')
            )
                ->addColumn(
                    'sku',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '60',
                    [],
                    'sku'
                )

                ->addColumn(
                    'paese',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '20',
                    [],
                    'paese'
                )

                ->addColumn(
                    'prezzo',
                    \Magento\Framework\DB\Ddl\Table::TYPE_DECIMAL,
                    '12,4',
                    ['nullable' => false, 'default' => '0.0000'],
                    'prezzo'
                )

                ->addColumn(
                    'valuta',
                    \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    '3',
                    [],
                    'valuta'
                )
                ->addColumn(
                    'meta_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
                    'flow_channels'
                )
                ->addColumn(
                    'meta_ref_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    '11',
                    [],
                    'meta_ref_id'
                )
                ->addColumn(
                    'meta_file',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [],
                    'meta_file'
                )

                ->addColumn(
                    'meta_processed',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    '1',
                    [],
                    'meta_processed'
                )
                ->addColumn(
                    'meta_insert_time',
                    \Magento\Framework\DB\Ddl\Table::TYPE_DATETIME,
                    '10',
                    ['unsigned' => true, 'nullable' => false],
                    'meta_insert_time'
                )

                ->addColumn(
                    'meta_process_time',
                    \Magento\Framework\DB\Ddl\Table::TYPE_DATETIME,
                    '10',
                    [],
                    'meta_process_time'
                );

            $installer->getConnection()->createTable($table);
        }

        $installer->endSetup();

    }

}
